2026-03-30 Version: 3.3.0
- Support API AddCloudAccess.
- Support API CreateWHClientCertificate.
- Support API CreateWarehouse.
- Support API DeleteCloudAccess.
- Support API DeleteWarehouse.
- Support API DescribeWarehouseCert.
- Support API ListWarehouse.
- Support API RevokeWHClientCertificate.
- Support API UploadPCACert.


2026-03-02 Version: 3.2.0
- Support API GetAssetCount.
- Support API GetRiskCount.
- Support API ListAssetCount.


2026-01-31 Version: 3.1.0
- Support API ApplyCertificate.
- Support API CancelPendingCertificate.
- Support API DeleteInstance.
- Support API GetCertificateDetail.
- Support API GetInstanceDetail.
- Support API GetInstanceSummary.
- Support API GetTaskAttribute.
- Support API ListCertificates.
- Support API ListInstances.
- Support API RefundInstance.
- Support API RevokeCertificate.
- Support API UpdateInstance.


2026-01-06 Version: 3.0.5
- Update API Decrypt: add request parameters WarehouseId.
- Update API Encrypt: add request parameters WarehouseId.
- Update API GetCertWarehouseQuota: add response parameters Body.AppTotalQuota.
- Update API GetCertWarehouseQuota: add response parameters Body.AppUseCount.
- Update API Sign: add request parameters WarehouseId.
- Update API Verify: add request parameters WarehouseId.


2025-12-23 Version: 3.0.4
- Update API Decrypt: add request parameters CustomIdentifier.
- Update API Encrypt: add request parameters CustomIdentifier.
- Update API Sign: add request parameters CustomIdentifier.
- Update API Verify: add request parameters CustomIdentifier.


2025-09-28 Version: 3.0.3
- Generated python 2020-04-07 for cas.

2025-09-15 Version: 3.0.2
- Update API GetUserCertificateDetail: add response parameters Body.Tags.


2025-07-23 Version: 3.0.1
- Update API DescribeCertificateState: add response parameters Body.CertId.


2025-02-18 Version: 3.0.0
- Update API GetUserCertificateDetail: update response param.
- Update API UploadUserCertificate: update response param.


2024-12-11 Version: 2.0.4
- Generated python 2020-04-07 for cas.

2024-12-10 Version: 2.0.3
- Update API CreateCertificateForPackageRequest: add param Tags.
- Update API CreateCertificateRequest: add param Tags.
- Update API CreateCertificateWithCsrRequest: add param Tags.
- Update API RenewCertificateOrderForPackageRequest: add param Tags.
- Update API UploadUserCertificate: add param Tags.


2024-11-22 Version: 2.0.2
- Update API GetUserCertificateDetail: update response param.


2024-09-23 Version: 2.0.1
- Update API GetUserCertificateDetail: update response param.


2024-08-30 Version: 2.0.0
- Delete API CreateWHClientCertificate.
- Delete API RevokeWHClientCertificate.
- Delete API UploadPCACert.


2024-08-21 Version: 1.7.0
- Support API CreateCsr.
- Support API CreateDeploymentJob.
- Support API DeleteCsr.
- Support API DeleteDeploymentJob.
- Support API DeleteWorkerResource.
- Support API DescribeCloudResourceStatus.
- Support API DescribeDeploymentJob.
- Support API DescribeDeploymentJobStatus.
- Support API GetCsrDetail.
- Support API ListCloudAccess.
- Support API ListCloudResources.
- Support API ListContact.
- Support API ListCsr.
- Support API ListDeploymentJob.
- Support API ListDeploymentJobCert.
- Support API ListDeploymentJobResource.
- Support API ListWorkerResource.
- Support API MoveResourceGroup.
- Support API UpdateCsr.
- Support API UpdateDeploymentJob.
- Support API UpdateDeploymentJobStatus.
- Support API UpdateWorkerResourceStatus.
- Support API UploadCsr.
- Update API GetUserCertificateDetail: update response param.


2024-08-20 Version: 1.6.0
- Support API CreateCsr.
- Support API CreateDeploymentJob.
- Support API DeleteCsr.
- Support API DeleteDeploymentJob.
- Support API DeleteWorkerResource.
- Support API DescribeCloudResourceStatus.
- Support API DescribeDeploymentJob.
- Support API DescribeDeploymentJobStatus.
- Support API GetCsrDetail.
- Support API ListCloudAccess.
- Support API ListCloudResources.
- Support API ListContact.
- Support API ListCsr.
- Support API ListDeploymentJob.
- Support API ListDeploymentJobCert.
- Support API ListDeploymentJobResource.
- Support API ListWorkerResource.
- Support API MoveResourceGroup.
- Support API UpdateCsr.
- Support API UpdateDeploymentJob.
- Support API UpdateDeploymentJobStatus.
- Support API UpdateWorkerResourceStatus.
- Support API UploadCsr.
- Update API GetUserCertificateDetail: update response param.


2024-08-13 Version: 1.5.0
- Support API CreateCsr.
- Support API CreateDeploymentJob.
- Support API DeleteCsr.
- Support API DeleteDeploymentJob.
- Support API DeleteWorkerResource.
- Support API DescribeCloudResourceStatus.
- Support API DescribeDeploymentJob.
- Support API DescribeDeploymentJobStatus.
- Support API GetCsrDetail.
- Support API ListCloudAccess.
- Support API ListCloudResources.
- Support API ListContact.
- Support API ListCsr.
- Support API ListDeploymentJob.
- Support API ListDeploymentJobCert.
- Support API ListDeploymentJobResource.
- Support API ListWorkerResource.
- Support API MoveResourceGroup.
- Support API UpdateCsr.
- Support API UpdateDeploymentJob.
- Support API UpdateDeploymentJobStatus.
- Support API UpdateWorkerResourceStatus.
- Support API UploadCsr.
- Update API GetUserCertificateDetail: update response param.


2024-06-13 Version: 1.4.0
- Support API CreateCsr.
- Support API CreateDeploymentJob.
- Support API DeleteCsr.
- Support API DeleteDeploymentJob.
- Support API DeleteWorkerResource.
- Support API DescribeCloudResourceStatus.
- Support API DescribeDeploymentJob.
- Support API DescribeDeploymentJobStatus.
- Support API GetCsrDetail.
- Support API ListCloudAccess.
- Support API ListCloudResources.
- Support API ListContact.
- Support API ListCsr.
- Support API ListDeploymentJob.
- Support API ListDeploymentJobCert.
- Support API ListDeploymentJobResource.
- Support API ListWorkerResource.
- Support API MoveResourceGroup.
- Support API UpdateCsr.
- Support API UpdateDeploymentJob.
- Support API UpdateDeploymentJobStatus.
- Support API UpdateWorkerResourceStatus.
- Support API UploadCsr.


2024-05-06 Version: 1.3.0
- Support API CreateCsr.
- Support API CreateDeploymentJob.
- Support API DeleteCsr.
- Support API DeleteDeploymentJob.
- Support API DeleteWorkerResource.
- Support API DescribeCloudResourceStatus.
- Support API DescribeDeploymentJob.
- Support API DescribeDeploymentJobStatus.
- Support API GetCsrDetail.
- Support API ListCloudAccess.
- Support API ListCloudResources.
- Support API ListContact.
- Support API ListCsr.
- Support API ListDeploymentJob.
- Support API ListDeploymentJobCert.
- Support API ListDeploymentJobResource.
- Support API ListWorkerResource.
- Support API UpdateCsr.
- Support API UpdateDeploymentJob.
- Support API UpdateDeploymentJobStatus.
- Support API UpdateWorkerResourceStatus.
- Support API UploadCsr.


2024-03-13 Version: 1.2.0
- Support API CreateCsr.
- Support API CreateDeploymentJob.
- Support API DeleteCsr.
- Support API DeleteDeploymentJob.
- Support API DeleteWorkerResource.
- Support API DescribeDeploymentJobStatus.
- Support API GetCsrDetail.
- Support API ListCloudResources.
- Support API ListCsr.
- Support API ListDeploymentJob.
- Support API ListDeploymentJobCert.
- Support API ListDeploymentJobResource.
- Support API UpdateCsr.
- Support API UpdateDeploymentJob.
- Support API UpdateDeploymentJobStatus.
- Support API UpdateWorkerResourceStatus.
- Support API UploadCsr.


2024-02-27 Version: 1.1.0
- Support API CreateCsr.
- Support API DeleteCsr.
- Support API GetCsrDetail.
- Support API ListCsr.
- Support API UpdateCsr.
- Support API UploadCsr.


2024-02-23 Version: 1.0.16
- Generated python 2020-04-07 for cas.

2023-12-20 Version: 1.0.15
- Generated python 2020-04-07 for cas.

2023-12-19 Version: 1.0.14
- Generated python 2020-04-07 for cas.

2022-11-30 Version: 1.0.13
- Support resourceGroup.

2022-11-24 Version: 1.0.12
- Support deleteCertificate.

2022-11-17 Version: 1.0.11
- Support GetCertWarehouseQuota.

2022-11-07 Version: 1.0.9
- Support encrypt and decrypt.

2022-11-03 Version: 1.0.8
- Support encrypt and decrypt.

2022-09-23 Version: 1.0.7
- Support SSL Sign.

2022-09-15 Version: 1.0.6
- Support Certificate Warehouse.

2022-03-16 Version: 1.0.5
- Fixed ListUserCertificateOrder API response error bug.

2022-03-16 Version: 1.0.4
- Fixed ListUserCertificateOrder API response error bug.

2022-02-24 Version: 1.0.3
- Add ListUserCertificateOrder API.

2021-12-21 Version: 1.0.2
- Support New SDK.

2021-03-30 Version: 1.0.1
- Generated python 2020-04-07 for cas.

2020-12-29 Version: 1.0.0
- AMP Version Change.

